@@ -47,6 +47,7 @@ typedef struct {
 	guint release_timeout_id;
 	GdkPoint buffer[DRAG_HISTORY];
 	GdkPoint momentum;
+	gboolean in_notify;
 } DragInfo;
 
 /* Autoscrolling */
@@ -226,6 +227,7 @@ struct _EvView {
 	EvViewWindowChild *window_child_focus;
 	AddingAnnotInfo    adding_annot_info;
 	MovingAnnotInfo    moving_annot_info;
+	GHashTable        *annot_window_map;
 
 	/* Focus */
 	EvMapping *focused_element;
